==> fyreonlib-0.1-sources.jar: com/vrs/android/fyreon/tutorials/WizardFragment.java <==
/**---------------------------------------------------------------------------------
 File Name : TutorialWizard.java
 Version Information : Version 1.1
 Date of Creation : 25/2/15
 Copyright Notice : This file is created by Virtual Reality Systems and all right reserve by VRS.
 -----------------------------------------------------------------------------------*/
package com.vrs.android.fyreon.tutorials;

import android.os.Bundle;
import android.support.annotation.Nullable;
import android.support.v4.app.Fragment;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;

import com.vrs.android.fyreon.R;

/**
 * ---------------------------------------------------------------------------------
 * Class Name : WizardFragment
 * Description : User guide tutorial wizard
 * Date of Creation : 07/04/14
 *
 * @author Virtual Reality systems
 *         <p/>
 *         -----------------------------------------------------------------------------------
 *         Update Log:
 *         Date:		By:		    Details:
 *         07/04/14     Bhadresh    Full class created
 *         -----------------------------------------------------------------------------------
 */
public class WizardFragment extends Fragment {
    @Override
    public View onCreateView(LayoutInflater inflater, @Nullable ViewGroup container, @Nullable Bundle savedInstanceState) {
        View rootView = inflater.inflate(R.layout.activity_tutorial, container, false);
        getActivity().getSupportFragmentManager().beginTransaction().
                replace(R.id.wizard_container, new TutorialWizard()).commit();
        Log.d("Wizard Fragment", "Wizard Fragment On Create View");
//        StepPagerStrip mStepPagerStrip = (StepPagerStrip) rootView.findViewById(R.id.strip);
//        mStepPagerStrip
//                .setOnPageSelectedListener(new StepPagerStrip.OnPageSelectedListener() {
//                    @Override
//                    public void onPageStripSelected(int position) {
////                        position = Math.min(mPagerAdapter.getCount() - 1,
////                                position);
////                        if (mPager.getCurrentItem() != position) {
////                            mPager.setCurrentItem(position);
////                        }
//                    }
//                });
        return rootView;
    }
}

==> fyreonlib-0.2.4-sources.jar: com/vrs/android/fyreon/tutorials/WizardFragment.java <==
/**---------------------------------------------------------------------------------
 File Name : TutorialWizard.java
 Version Information : Version 1.1
 Date of Creation : 25/2/15
 Copyright Notice : This file is created by Virtual Reality Systems and all right reserve by VRS.
 -----------------------------------------------------------------------------------*/
package com.vrs.android.fyreon.tutorials;

import android.os.Bundle;
import android.support.annotation.Nullable;
import android.support.v4.app.Fragment;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;

import com.vrs.android.fyreon.R;
import com.vrs.android.fyreon.utils.logger.Logger;

/**
 * ---------------------------------------------------------------------------------
 * Class Name : WizardFragment
 * Description : User guide tutorial wizard
 * Date of Creation : 07/04/14
 *
 * @author Virtual Reality systems
 *         <p/>
 *         -----------------------------------------------------------------------------------
 *         Update Log:
 *         Date:		By:		    Details:
 *         07/04/14     Bhadresh    Full class created
 *         -----------------------------------------------------------------------------------
 */
public class WizardFragment extends Fragment {
    private static final Logger logger = new Logger(true, WizardFragment.class.getSimpleName());
    @Override
    public View onCreateView(LayoutInflater inflater, @Nullable ViewGroup container, @Nullable Bundle savedInstanceState) {
        View rootView = inflater.inflate(R.layout.activity_tutorial, container, false);
        getActivity().getSupportFragmentManager().beginTransaction().
                replace(R.id.wizard_container, new TutorialWizard()).commit();
        logger.debug("Wizard Fragment", "Wizard Fragment On Create View");
//        StepPagerStrip mStepPagerStrip = (StepPagerStrip) rootView.findViewById(R.id.strip);
//        mStepPagerStrip
//                .setOnPageSelectedListener(new StepPagerStrip.OnPageSelectedListener() {
//                    @Override
//                    public void onPageStripSelected(int position) {
////                        position = Math.min(mPagerAdapter.getCount() - 1,
////                                position);
////                        if (mPager.getCurrentItem() != position) {
////                            mPager.setCurrentItem(position);
////                        }
//                    }
//                });
        return rootView;
    }
}
